@@ -19,31 +19,16 @@
 """
 Delegation utilities
 
-Classes:
-
-    `Delegator`
-        An AttributeCollection that delegates attributes
-
-    `DelegatorFactory`
-        Allows easy creation of delegators with profiles
-
-    `Profile`
-        A delegation profile, states what to delegate
-
-Decorators:
-
-    `delegator_factory`
-        Installs a `DelegatorFactory` on an `AttributeCollectionBase`
-
-    `delegated`
-        Includes the decorated attribute in the specified delegation profile
+These utilities are a front-end to the aop package.
 """
 
+# Note: User won't delegate any private vars, or at least shouldn't. So no
+# mangling should be done in this package
+
 __docformat__ = 'reStructuredText'
 
 # place these in our namespace, naughty naughty
+from .delegationaspect import DelegationAspect
 from .profile import Profile
-from .delegator import Delegator
-from .delegatorfactory import DelegatorFactory
-from .decorators import delegator_factory, delegated
+from .decorators import profile_carrier, in_profile
 
