@@ -30,13 +30,6 @@ Classes:
     `RestrictedDispatcher`
         `Dispatcher` wrapper that filters the list of supported events.
 
-Decorators:
-
-    `dispatcher`
-        Installs a `Dispatcher` on an `AttributeCollectionBase`.
-
-    `dispatcher_switch`
-        Installs a `DispatcherSwitch` on an `AttributeCollectionBase`.
 """
 
 __docformat__ = 'reStructuredText'
@@ -44,5 +37,4 @@ __docformat__ = 'reStructuredText'
 from .dispatcher_ import Dispatcher, UnsupportedEventError
 from .dispatcherswitch import DispatcherSwitch
 from .restricteddispatcher import RestrictedDispatcher
-from .decorators import dispatcher, dispatcher_switch
 
