@@ -20,10 +20,13 @@ __docformat__ = 'reStructuredText'
 
 from . import UnsupportedEventError
 
+# Note: could have done this with an aspect as well
 class RestrictedDispatcher(object):
 
     """
-    `Dispatcher` wrapper that filters the list of supported events.
+    A restricted view of a `Dispatcher`
+    
+    The list of supported events is filtered.
 
     Check `Dispatcher` for the documentation of the methods that are left
     undocumented here.
