@@ -18,34 +18,25 @@
 
 """
 All sorts of geometry trinkets
-
-Classes:
-
-    `Vector`
-        2D Point/Vector
-
-    `BoundVector`
-        `Vector` whose x and y values are stored elsewhere.
-
-    `ImmutableVector`
-        `Vector` wrapper that makes the vector immutable.
-
-    `VerboseVector`
-        `Vector` wrapper that sends out events.
-
-    `Rectangle`
-        A rectangle identified by two points.
-
-    `VerboseRectangle`
-        `Rectangle` wrapper that sends out events
 """
 
 __docformat__ = 'reStructuredText'
 
 from .vector import Vector
-from .verbosevector import VerboseVector
-from .immutablevector import ImmutableVector
-from .boundvector import BoundVector
+from .immutablevector import ImmutableVector, immutable_vector_aspect
+from .discretevector import DiscreteVector
+from .verbosevectoraspect import verbose_vector_aspect
+
 from .rectangle import Rectangle
-from .verboserectangle import VerboseRectangle
+from .immutablerectangle import ImmutableRectangle, immutable_rectangle_aspect
+from .discreterectangle import DiscreteRectangle
+from .verboserectangleaspect import verbose_rectangle_aspect
+
+# bit of nasty ugly code follows (huge coupling, but meh, it's contained to a
+# small part)
+from ._vectorbase import _VectorBase
+from .functions import _get_vector_operator
+_VectorBase._get_vector_operator = _get_vector_operator
+del _get_vector_operator
+del _VectorBase
 
