@@ -18,32 +18,6 @@
 
 '''
 Function overloading tools.
-
-Classes:
-
-    `Parameter`
-        A parameter of an operation.
-
-    `Param`
-        Alias for `Parameter`
-
-    `CompositeParameter`
-        `Parameter` that consists of more parameters.
-
-    `CompositeParam`
-        Alias for `CompositeParameter`
-
-    `Overloader`
-        A collection of `Overload`s that can process calls.
-
-    `Overload`
-        An operation signature with an operation to call when arguments match.
-
-
-Decorators:
-
-    `overloaded`
-        Overloads an operation.
 '''
 
 __docformat__ = 'reStructuredText'
