@@ -36,34 +36,30 @@ class CompositeParameter(Parameter):
     expanded. E.g. for a composite parameter with childs 'x' and 'y', a read
     value of (1, 3) and a dict d of {}; after writing to d, d will equal {x:1, y:3},
     and not {{x:1, y:3}}.
-
-    Methods:
-        
-        - all of `Parameter`
     """
 
     def __init__(self, name, params, matcher = (tuple, list, dict), *args, **kwargs):
         """
         Construct a `CompositeParameter`.
 
-        Parameters:
+        :param name: name of the parameter, used for keyword arguments. Must be
+                     unique.
+        :type name: string
 
-            `name` :: string
-                name of the parameter, used for keyword arguments. Must be
-                unique.
+        :param params: the child parameters of the composite
+        :type params: (Parameter...)
 
-            `params` :: (Parameter...)
-                the child parameters of the composite
-
-            `matcher` :: f(value) -> matched::bool
-                      :: (type...) = (tuple, list, dict)
-                      :: type
-                the parameter will match only if this matcher matches the arg
-                and its child args match the elements of the arg. It is
-                unlikely you'll need a value other than the default.
+        :param matcher: Either of:
             
-            `default`
-                default value for the parameter, omit if param has no default
+            - f(value) -> matched:bool
+            - (type...) = (tuple, list, dict)
+            - type
+
+            the parameter will match only if this matcher matches the arg
+            and its child args match the elements of the arg. It is
+            unlikely you'll need a value other than the default.
+        
+        :param default: default value for the parameter, omit if param has no default
         """
         Parameter.__init__(self, name, matcher, *args, **kwargs)
         self.__params = params
@@ -102,7 +98,6 @@ class CompositeParameter(Parameter):
         for param in self.__params:
             param.write(kwargs)
 
-
 # a shortcut
 CompositeParam = CompositeParameter
 
