@@ -26,17 +26,13 @@ _logger = logging.getLogger("pytilities.overloading.overloader")
 
 class Overloader(object):
     """
-    A collection of `Overload`s that can process calls.
+    A collection of `Overload`'s that can process calls.
 
     Tool for overloading operations.
     
     Has an ordered collection of overloads which serve as rules, the operation
     of the matching overload is called. If none match, an assertion error is
     raised.
-
-    Methods:
-
-        - `process_call`: Process a call with given args and keyword args
     """
 
     def __init__(self, overloads, add_self = True):
@@ -65,26 +61,39 @@ class Overloader(object):
             for overload in overloads:
                 overload.insert_params(0, self_param)
 
-    def process_call(self, args, kwargs):
+    def process_args(self, *args, kwargs={}):
+        """
+        Process given args and keyword args.
+
+        Return the callable that would be called and the args it'd receive.
+        
+        :param args: arguments of the call
+        :param kwargs: keyword arguments of the call
+        :return: (processed_args, callable).
+        :rtype: ({string: object}, callable)
+        """
+
+        for overload in self.__overloads:
+            retval = overload.process_args(*args, kwargs=kwargs)
+            if retval: 
+                return retval
+
+        assert False, (
+            "Failed to find matching overload for args%s, kwargs%s" % 
+            (args, kwargs)
+        )
+
+    # Note: not using **kwargs allows passing self by kwargs
+    def process_call(self, *args, kwargs={}):
         """
         Process a call with given args and keyword args.
         
         The matching overload is called.
 
-        Parameters:
-
-            `args`, `kwargs'
-                arguments of the call
-
-        Returns the return value of the called operation
+        :param args: arguments of the call
+        :param kwargs: keyword arguments of the call
+        :return: the return value of the called operation
         """
-
-        _logger.debug("Processing call")
-
-        for overload in self.__overloads:
-            (matched, return_value) = overload.process_call(args, kwargs)
-            if matched: 
-                return return_value
-
-        assert False, "Failed to find matching overload for given"
+        (processed_args, operation) = self.process_args(*args, kwargs=kwargs)
+        return operation(**processed_args)
 
