@@ -33,74 +33,75 @@ class Parameter(object):
 
     Note that an argument matches a parameter, if its matcher returns True on
     the argument value or the parameter has a default.
-
-    Methods:
-
-        - `read_arg`: Read/process the given arg.
-        - `read_kwargs`: Look in a dict for a matching arg and process its value
-        - `write`: Adds the last read argument value to a dictionary.
     """
 
     # support multiple types per param? Wait for a feature request first
-    def __init__(self, name, matcher = matches_everything, *args, **kwargs):
+    def __init__(self, name, *args, **kwargs):
         """
         Construct a `Parameter`.
 
-        Parameters:
+        :param name: name of parameter as specified in keyword arguments
+        :type name: string
 
-            `name` :: string
-                name of parameter as specified in keyword arguments
+        :param kwargs: Keyword parameters:
 
-            `matcher` :: 
-                Either of:
+            - `type_` or `types` or `matcher`:
+                type\_: type of the parameter
+                types: iterable of possible types for the parameter
+                matcher: a matcher function of type f(value) -> matched::bool
 
-                    - type of the parameter
-                    - iterable of possible types of param
-                    - a matcher function :: f(value) -> matched::bool
+                If given as first positional arg, type\_ is assumed.
+                If not given, will match any value.
             
-            `default`
+            - `default`:
                 default value for the parameter. Omit if param has no default
+                
+                Can also be given as second positional arg.
 
-        Preconditions:
-            1. `default` must match the specified matcher
+        :Preconditions: 1. `default` must match the specified matcher
         """
-
         assert name, "Name param musn't be empty or None"
-        assert isinstance(name, basestring), "Name must be a string"
-        assert len(args) <= 1, \
+        assert isinstance(name, str), "Name must be a string"
+        assert len(args) <= 2, \
             "Unexpected trailing args: %s" % args
-        assert not (args and "default" in kwargs), (
-            "Default specified twice: by *args(%s) and **kwargs(%s)" %
-            (args[0], kwargs["default"]))
+        assert not (args and "type_" in kwargs), (
+            "type_ specified twice: by *args(%s) and **kwargs(%s)" %
+            (args[0], kwargs["type_"]))
+        assert not (len(args) > 1 and "default" in kwargs), (
+            "default specified twice: by *args(%s) and **kwargs(%s)" %
+            (args[1], kwargs["default"]))
 
         self.__name = name
 
-        if hasattr(matcher, "__iter__"):
-            # iter of types
-            self._matcher = matches_type(*matcher)
-        elif isinstance(matcher, type):
-            # a single type
-            self._matcher = matches_type(matcher)
-        else:
-            # it's a matcher function
-            self._matcher = matcher
-
-        self.__has_default = True
+        # look for a match thingy
         if args:
-            self.__default = args[0]
-        elif "default" in kwargs:
-            self.__default = kwargs["default"]
-        else:
-            self.__has_default = False
+            self._matcher = matches_type(args[0])
+        elif 'type_' in kwargs:
+            self._matcher = matches_type(kwargs['type_'])
+        elif 'types' in kwargs:
+            self._matcher = matches_type(kwargs['types'])
+        elif 'matcher' in kwargs:
+            self._matcher = kwargs['matcher']
+        else: # default match all
+            self._matcher = matches_everything
 
-        assert not self.__has_default or \
-                self._matcher(self.__default), (
+        if len(args) > 1:
+            self._default = args[1]
+        elif "default" in kwargs:
+            self._default = kwargs["default"]
+
+        assert not hasattr(self, '_default') or \
+                self._matcher(self._default), (
                 "Default must match the given matcher as well. (Precondition 1) Default: %s" %
-                    (self.__default))
+                    (self._default))
 
         # whether or not last read was a match
         self.__matched = False
 
+    @property
+    def name(self):
+        return self.__name
+
     # Note: the two step (read all, then write) process is necessary to allow for
     # self validating parameters in the future. This allows them to return True at
     # read when they match, and throw errors at write when the overload apparantly
@@ -110,12 +111,10 @@ class Parameter(object):
         """
         Read/process the given arg.
         
-        Parameters:
+        :param arg: the argument value to read
 
-            `arg`
-                the argument value to read
-
-        Returns True if parameter matches `arg` :: bool
+        :return: True if parameter matches `arg`
+        :rtype: bool
         """
         self.__value = arg
         self.__matched = self._matcher(self.__value)
@@ -125,19 +124,17 @@ class Parameter(object):
         """
         Look in a dict for a matching arg and process its value.
 
-        Parameters:
-            
-            `kwargs` :: {name::string : value}
-                dictionary of arguments
+        :param kwargs: frozen dictionary of arguments
 
-        Returns True if a matching argument was found in `kwargs` :: bool
+        :return: True if a matching argument was found in `kwargs`
+        :rtype: bool
         """
 
         if self.__name in kwargs:
             return self.read_arg(kwargs[self.__name])
-        elif self.__has_default:
+        elif hasattr(self, '_default'):
             self.__matched = True
-            self.__value = self.__default
+            self.__value = self._default
         else:
             self.__matched = False
 
@@ -147,14 +144,9 @@ class Parameter(object):
         """
         Adds the last read argument value to a dictionary.
 
-        Parameters:
+        :param kwargs: the dictionary to add the last value and the parameter name to
 
-            `kwargs` :: {name::string : value}
-                the dictionary to add the last value and the parameter name to
-
-        Preconditions:
-
-            1. the parameter matched on the last read
+        :Preconditions: 1. the parameter matched on the last read
         """
 
         assert self.__matched, \
@@ -166,12 +158,14 @@ class Parameter(object):
     def _matched(self):
         return self.__matched
 
+    def __str__(self):
+        if hasattr(self, '_default'):
+            default = str(self._default)
+        else:
+            default = ''
+
+        return 'Parameter(name=%s, default=%s)' % (self.__name, default)
 
 # a shortcut
 Param = Parameter
 
-# TODO: write a validation.py or something like that, add in lots of fun stuff
-# like self-validating Parameters that we can then use here! (e.g. check for
-# None values etc)
-# or add using Strategy pattern: Validator(s)
-
