@@ -18,6 +18,8 @@
 
 __docformat__ = 'reStructuredText'
 
+from pytilities.infinity import infinity, negative_infinity
+
 class _NumberTypeMeta(type):
     def __instancecheck__(self, instance):
         return issubclass(type(instance), self)
@@ -28,7 +30,8 @@ class _NumberTypeMeta(type):
         if subclass is self:
             return True
 
-        for type_ in (int, long, float):
+        for type_ in (int, float, infinity.__class__,
+                      negative_infinity.__class__):
             if issubclass(type_, subclass):
                 return True
 
