@@ -18,13 +18,15 @@
 
 __docformat__ = 'reStructuredText'
 
+from pytilities.infinity import infinity, negative_infinity
+
 class _NumericTypeMeta(type):
     def __instancecheck__(self, instance):
         try:
             float(instance)
             return True
         except (ValueError, TypeError):
-            return False
+            return instance in (infinity, negative_infinity)
 
     # inside meta classes, self refers to the class that has this meta as
     # metaclass
@@ -35,7 +37,8 @@ class _NumericTypeMeta(type):
         if subclass is self:
             return True
 
-        for type_ in (int, long, float):
+        for type_ in (int, float, infinity.__class__,
+                      negative_infinity.__class__):
             if issubclass(type_, subclass):
                 return True
 
