@@ -20,13 +20,13 @@ __docformat__ = 'reStructuredText'
 
 from . import _NumericTypeMeta
 
-class NumericType(object):
+class NumericType(object, metaclass=_NumericTypeMeta):
     """
     Represents any numeric type.
     
-    Numeric strings, ints (, longs) and floats are indirect instances of this
-    class. Ints (, longs) and floats are subclasses of this class. Note that a
+    Numeric strings, ints, floats and infinity are indirect instances of this
+    class. Ints and floats are subclasses of this class. Note that a
     string is not a subclass (some strings are numeric, but not all, and there
     is no numeric string type).
     """
-    __metaclass__ = _NumericTypeMeta
+    
