@@ -20,7 +20,7 @@ __docformat__ = 'reStructuredText'
 
 from . import _SequenceTypeMeta
 
-class SequenceType(object):
+class SequenceType(object, metaclass=_SequenceTypeMeta):
     """
     Represents any ordered sequence.
 
@@ -28,5 +28,4 @@ class SequenceType(object):
 
     Lists and tuples are subtypes of this type.
     """
-    __metaclass__ = _SequenceTypeMeta
 
